@@ -7,7 +7,7 @@ DataBackendCbind = R6Class("DataBackendCbind", inherit = DataBackend, cloneable
       pk = b1$primary_key
 
       if (pk != b2$primary_key) {
-        stopf("All backends to cbind must have the primary_key '%s'", pk)
+        error_input("All backends to cbind must have the primary_key '%s'", pk)
       }
 
       super$initialize(list(b1 = b1, b2 = b2), pk)
