@@ -77,7 +77,7 @@ LearnerClassif = R6Class("LearnerClassif", inherit = Learner,
     #'
     #' @return `list()` with elements `"response"` or `"prob"` depending on the predict type.
     predict_newdata_fast = function(newdata, task = NULL) {
-      if (is.null(task) && is.null(self$state$train_task)) stopf("No task stored, and no task provided")
+      if (is.null(task) && is.null(self$state$train_task)) error_input("No task stored, and no task provided")
       feature_names = self$state$train_task$feature_names %??% task$feature_names
       class_names = self$state$train_task$class_names %??% task$class_names
 
