@@ -113,7 +113,7 @@ LearnerClassifDebug = R6Class("LearnerClassifDebug", inherit = LearnerClassif,
     #' @return Named `numeric()`.
     importance = function() {
       if (is.null(self$model)) {
-        stopf("No model stored")
+        error_input("No model stored")
       }
       fns = self$state$feature_names
       set_names(rep(0, length(fns)), fns)
@@ -124,7 +124,7 @@ LearnerClassifDebug = R6Class("LearnerClassifDebug", inherit = LearnerClassif,
     #' @return `character()`.
     selected_features = function() {
       if (is.null(self$model)) {
-        stopf("No model stored")
+        error_input("No model stored")
       }
       character(0)
     }
@@ -180,10 +180,10 @@ LearnerClassifDebug = R6Class("LearnerClassifDebug", inherit = LearnerClassif,
         message("Message from classif.debug->train()")
       }
       if (roll("warning_train")) {
-        warningf("Warning from classif.debug->train()")
+        warning_mlr3("Warning from classif.debug->train()")
       }
       if (roll("error_train")) {
-        stopf("Error from classif.debug->train()")
+        error_learner_train("Error from classif.debug->train()")
       }
       if (roll("segfault_train")) {
         get("attach")(structure(list(), class = "UserDefinedDatabase"))
@@ -192,18 +192,15 @@ LearnerClassifDebug = R6Class("LearnerClassifDebug", inherit = LearnerClassif,
       valid_truth = if (!is.null(task$internal_valid_task)) task$internal_valid_task$truth()
 
       if (isTRUE(pv$early_stopping) && is.null(valid_truth)) {
-        stopf("Early stopping is only possible when a validation task is present.")
+        error_config("Early stopping is only possible when a validation task is present.")
       }
 
       model = list(
-          response = as.character(sample(task$truth(), 1L, prob = private$.get_weights(task))),
-          pid = Sys.getpid(),
-          id = UUIDgenerate(),
-          random_number = sample(100000, 1),
-          iter = if (isTRUE(pv$early_stopping))
-            sample(pv$iter %??% 1L, 1L)
-          else
-            pv$iter %??% 1L
+        response = as.character(sample(task$truth(), 1L, prob = private$.get_weights(task))),
+        pid = Sys.getpid(),
+        id = UUIDgenerate(),
+        random_number = sample(100000, 1),
+        iter = if (isTRUE(pv$early_stopping)) sample(pv$iter %??% 1L, 1L) else pv$iter %??% 1L
       )
 
       if (!is.null(valid_truth)) {
@@ -248,7 +245,7 @@ LearnerClassifDebug = R6Class("LearnerClassifDebug", inherit = LearnerClassif,
     },
     .predict = function(task) {
       if (!is.null(self$model$marshal_pid) && self$model$marshal_pid != Sys.getpid()) {
-        stopf("Model was not unmarshaled correctly")
+        error_mlr3("Model was not unmarshaled correctly")
       }
       n = task$nrow
       pv = self$param_set$get_values(tags = "predict")
@@ -265,10 +262,10 @@ LearnerClassifDebug = R6Class("LearnerClassifDebug", inherit = LearnerClassif,
         message("Message from classif.debug->predict()")
       }
       if (roll("warning_predict")) {
-        warningf("Warning from classif.debug->predict()")
+        warning_mlr3("Warning from classif.debug->predict()")
       }
       if (roll("error_predict")) {
-        stopf("Error from classif.debug->predict()")
+        error_learner_predict("Error from classif.debug->predict()")
       }
       if (roll("segfault_predict")) {
         get("attach")(structure(list(), class = "UserDefinedDatabase"))
