@@ -54,7 +54,7 @@ LearnerClassifFeatureless = R6Class("LearnerClassifFeatureless", inherit = Learn
     #' @return Named `numeric()`.
     importance = function() {
       if (is.null(self$model)) {
-        stopf("No model stored")
+        error_learner("No model stored")
       }
       fn = self$model$features
       named_vector(fn, 0)
@@ -65,7 +65,7 @@ LearnerClassifFeatureless = R6Class("LearnerClassifFeatureless", inherit = Learn
     #' @return `character(0)`.
     selected_features = function() {
       if (is.null(self$model)) {
-        stopf("No model stored")
+        error_learner("No model stored")
       }
       character()
     }
