@@ -45,7 +45,7 @@ ResamplingHoldout = R6Class("ResamplingHoldout", inherit = Resampling,
       ps = ps(
         ratio = p_dbl(0, 1, tags = "required")
       )
-      ps$values = list(ratio = 2 / 3)
+      ps$set_values(ratio = 2 / 3)
 
       super$initialize(id = "holdout", param_set = ps,
         label = "Holdout", man = "mlr3::mlr_resamplings_holdout")
