@@ -12,9 +12,21 @@ as_learner = function(x, ...) { # nolint
 }
 
 #' @export
+#' @param discard_state (`logical(1)`)
+#'   Whether to discard the state.
 #' @rdname as_learner
-as_learner.Learner = function(x, clone = FALSE, ...) { # nolint
-  if (isTRUE(clone)) x$clone(deep = TRUE) else x
+as_learner.Learner = function(x, clone = FALSE, discard_state = FALSE, ...) { # nolint
+  assert_empty_ellipsis(...)
+  if (isTRUE(clone) && isTRUE(discard_state)) {
+    clone_without(x, "state")
+  } else if (isTRUE(clone)) {
+    x$clone(deep = TRUE)
+  } else if (isTRUE(discard_state)) {
+    x$state = NULL
+    x
+  } else {
+    x
+  }
 }
 
 #' @export
