@@ -20,7 +20,7 @@ default_fallback = function(learner, ...) {
 #' @export
 default_fallback.Learner = function(learner, ...) {
   # FIXME: remove when new encapsulate/fallback system is in place
-  return(NULL)
+  NULL
 }
 
 #' @rdname default_fallback
@@ -30,12 +30,12 @@ default_fallback.LearnerClassif = function(learner, ...) {
 
   # set predict type
   if (learner$predict_type %nin% fallback$predict_types) {
-    stopf("Fallback learner '%s' does not support predict type '%s'.", fallback$id, learner$predict_type)
+    error_input("Fallback learner '%s' does not support predict type '%s'.", fallback$id, learner$predict_type)
   }
 
   fallback$predict_type = learner$predict_type
 
-  return(fallback)
+  fallback
 }
 
 #' @rdname default_fallback
@@ -45,7 +45,7 @@ default_fallback.LearnerRegr = function(learner, ...) {
 
   # set predict type
   if (learner$predict_type %nin% fallback$predict_types) {
-    stopf("Fallback learner '%s' does not support predict type '%s'.", fallback$id, learner$predict_type)
+    error_config("Fallback learner '%s' does not support predict type '%s'.", fallback$id, learner$predict_type)
   }
 
   fallback$predict_type = learner$predict_type
@@ -54,12 +54,12 @@ default_fallback.LearnerRegr = function(learner, ...) {
   if (learner$predict_type == "quantiles") {
 
     if (is.null(learner$quantiles) || is.null(learner$quantile_response)) {
-      stopf("Cannot set quantiles for fallback learner. Set `$quantiles` and `$quantile_response` in %s.", learner$id)
+      error_config("Cannot set quantiles for fallback learner. Set `$quantiles` and `$quantile_response` in %s.", learner$id)
     }
 
     fallback$quantiles = learner$quantiles
     fallback$quantile_response = learner$quantile_response
   }
 
-  return(fallback)
+  fallback
 }
